@@ -95,6 +95,7 @@ func TestFloatingIPFromSchema(t *testing.T) {
 	t.Run("IPv6", func(t *testing.T) {
 		data := []byte(`{
 			"id": 4711,
+			"name": "Web Frontend",
 			"description": "Web Frontend",
 			"created":"2017-08-16T17:29:14+00:00",
 			"ip": "2001:db8::/64",
@@ -133,6 +134,9 @@ func TestFloatingIPFromSchema(t *testing.T) {
 		if !floatingIP.Blocked {
 			t.Errorf("unexpected value for Blocked: %v", floatingIP.Blocked)
 		}
+		if floatingIP.Name != "Web Frontend" {
+			t.Errorf("unexpected name: %v", floatingIP.Name)
+		}
 		if floatingIP.Description != "Web Frontend" {
 			t.Errorf("unexpected description: %v", floatingIP.Description)
 		}
@@ -751,7 +755,8 @@ func TestSSHKeyFromSchema(t *testing.T) {
 		"labels": {
 			"key": "value",
 			"key2": "value2"
-		}
+		},
+		"created":"2017-08-16T17:29:14+00:00"
 	}`)
 
 	var s schema.SSHKey
@@ -775,6 +780,9 @@ func TestSSHKeyFromSchema(t *testing.T) {
 	if sshKey.Labels["key"] != "value" || sshKey.Labels["key2"] != "value2" {
 		t.Errorf("unexpected labels: %v", sshKey.Labels)
 	}
+	if !sshKey.Created.Equal(time.Date(2017, 8, 16, 17, 29, 14, 0, time.UTC)) {
+		t.Errorf("unexpected created date: %v", sshKey.Created)
+	}
 }
 
 func TestErrorFromSchema(t *testing.T) {
